@@ -29,7 +29,7 @@ class EventListener(Generic[EventArgs], list):
     log: Optional[logging.Logger]
 
     def __init__(self, *args, log=None, raise_exceptions=False):
-        super().__init__(*args)
+        super().__init__(args)
         self.raise_exceptions = raise_exceptions
         self.log = log or logging
 
@@ -50,13 +50,13 @@ ZMQMessageSub = TypeVar('ZMQMessageSub', bound=ZMQMessage)
 
 
 class MessageDispatcher:
-    def __init__(self, name=None, raise_validation_errors=False, raise_handler_errors=False):
+    def __init__(self, name=None, *, raise_validation_errors=False, raise_handler_errors=False):
         """
         :param name: optionally name the dispatcher for logging purposes
         :param raise_validation_errors: if true and received messages do not match a validation error is raised,
                                         this is useful in restricive code or testcases
-        :param raise_validation_errors: if true and a message handler raises an exception, the exception is raised,
-                                        this is useful in restricive code or testcases
+        :param raise_handler_errors: if true and a message handler raises an exception, the exception is raised,
+                                     this is useful in restricive code or testcases
         """
         self.name = name
         self.log = logging.getLogger(f"{self.__class__.__name__}({self.name})")
@@ -105,8 +105,10 @@ class MessageDispatcher:
 
 
 class SubscribingMessageDispatcher(MessageDispatcher):
-    def __init__(self, subscribe: Callable[[bytes], None], name=None):
-        super().__init__(name=name)
+    def __init__(self, subscribe: Callable[[bytes], None], name=None, *, raise_validation_errors=False,
+                 raise_handler_errors=False):
+        super().__init__(name=name, raise_validation_errors=raise_validation_errors,
+                         raise_handler_errors=raise_handler_errors)
         self.subscribe = subscribe
 
     def register_handler(self, topic: Union[bytes, str],
@@ -114,5 +116,7 @@ class SubscribingMessageDispatcher(MessageDispatcher):
                          handler: Callable[[ZMQMessageSub], None], *,
                          filter: Optional[Dict] = None,
                          register_schema=True):
+        if topic and hasattr(topic, "encode"):
+            topic = topic.encode()
         self.subscribe(topic)
         return super().register_handler(topic, message_class, handler, filter=filter, register_schema=register_schema)
