@@ -19,6 +19,22 @@ class Medium(OpenModuleModel):
         return f"{self.type}:{_truncate(self.id)}"
 
 
+class QRMedium(Medium):
+    type: MediumType = "qr"
+
+
+class PINMedium(Medium):
+    type: MediumType = "pin"
+
+
+class NFCMedium(Medium):
+    type: MediumType = "nfc"
+
+
+class RegexMedium(Medium):
+    type: MediumType = "regex"
+
+
 class LPRCountry(OpenModuleModel):
     code: str
     state: str = ""
@@ -62,4 +78,6 @@ class Vehicle(OpenModuleModel):
 
     def __str__(self):
         media = ", ".join(str(x) for x in [self.lpr, self.qr, self.nfc] if x)
-        return f"Vehicle<id:{str(self.id)[-7:]}, {media}>"
+        if media:
+            media = ", " + media
+        return f"Vehicle<id:{str(self.id)[-7:]}{media}>"
