@@ -2,14 +2,12 @@ import ctypes
 import logging
 import threading
 import time
-from typing import Callable, Optional
 from unittest import TestCase
 
 from openmodule.config import override_settings
 from openmodule.core import shutdown_openmodule
 from openmodule.utils.schema import Schema
 from openmodule_test.health import HealthTestMixin
-from openmodule_test.zeromq import find_free_port
 
 
 class InterruptTestMixin(TestCase):
@@ -46,7 +44,10 @@ class InterruptTestMixin(TestCase):
     def function_wrapper(self, f):
         def wrapper():
             self.finished = False
-            f()
+            try:
+                f()
+            except Exception as e:
+                print(e)
             self.finished = True
 
         return wrapper
@@ -68,7 +69,6 @@ class InterruptTestMixin(TestCase):
                 time.sleep(0.5)
             else:
                 self.assertTrue(self.finished)
-
                 return
         self.async_raise(thread, SystemExit)
         raise AssertionError("Thread took to long for shutdown")
@@ -92,10 +92,9 @@ class InterruptTestMixin(TestCase):
         raise AssertionError("Thread took to long for shutdown")
 
 
-@override_settings(BROKER_SUB=f"tcp://127.0.0.1:{find_free_port()}",
-                   BROKER_PUB=f"tcp://127.0.0.1:{find_free_port()}")
 class MainTestMixin(HealthTestMixin, InterruptTestMixin):
     topics = ["healthz"]
+    protocol = "tcp://"
 
     def wait_for_setup(self):
         self.wait_for_health()
