@@ -49,7 +49,10 @@ def sleepy():
         while time.time() - t0 < 10:
             time.sleep(1)
     except Exception:
-        sleepy()
+        try:
+            sleepy()
+        except SystemExit:
+            pass
 
 
 class InterruptTimeoutTest(InterruptTestMixin, TestCase):
@@ -57,7 +60,7 @@ class InterruptTimeoutTest(InterruptTestMixin, TestCase):
 
     def test_exception(self):
         with self.assertRaises(AssertionError) as e:
-            self.exception_in_function(sleepy, Exception())
+            self.exception_in_function(sleepy, Exception)
         self.assertIn("Thread took to long for shutdown", str(e.exception))
 
 
